#ifndef ABOUTDIALOG_H		// -*- c++ -*-
#define ABOUTDIALOG_H
///
// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
///
#include "widget/dialogwrap.h"

/**
 * This is a singleton.
 */
class AboutDialog : public DialogWrap {
public:
  AboutDialog();
  static AboutDialog &instance();
private:
  void on_response(int);
  static AboutDialog *_instance;
};

#endif
